@@ -33,9 +33,10 @@
 #  define APPSTREAMQT_DEPRECATED_NO_EXPORT APPSTREAMQT_NO_EXPORT APPSTREAMQT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define APPSTREAMQT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef APPSTREAMQT_NO_DEPRECATED
+#    define APPSTREAMQT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
